==> ui-18.3.7.tgz: package/components/checkbox/Checkbox.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import { checkNodeExist, getClassName } from '@react-devui/utils';
import { useGeneralContext, useDValue } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { DBaseInput } from '../_base-input';
import { useFormControl } from '../form';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DCheckboxGroup } from './CheckboxGroup';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DCheckbox' });
export const DCheckbox = (props) => {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dRef, dFormControl, dModel, dDisabled = false, dIndeterminate = false, dInputRender, onModelChange } = _a, restProps = __rest(_a, ["children", "dRef", "dFormControl", "dModel", "dDisabled", "dIndeterminate", "dInputRender", "onModelChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gDisabled } = useGeneralContext();
    //#endregion
    const formControlInject = useFormControl(dFormControl);
    const [checked, changeChecked] = useDValue(false, dIndeterminate ? false : dModel, onModelChange, undefined, formControlInject);
    const disabled = dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled);
    return (_jsxs("label", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}checkbox`, {
            'is-indeterminate': dIndeterminate,
            'is-checked': checked,
            'is-disabled': disabled,
        }) }, { children: [_jsxs("div", Object.assign({ className: `${dPrefix}checkbox__state-container` }, { children: [_jsx(DBaseInput, Object.assign({ dFormControl: dFormControl, dLabelFor: true }, { children: ({ render: renderBaseInput }) => {
                            const input = renderBaseInput(_jsx("input", { ref: dRef === null || dRef === void 0 ? void 0 : dRef.input, className: `${dPrefix}checkbox__input`, type: "checkbox", disabled: disabled, "aria-checked": dIndeterminate ? 'mixed' : checked, onChange: () => {
                                    changeChecked(!checked);
                                } }));
                            return isUndefined(dInputRender) ? input : dInputRender(input);
                        } })), dIndeterminate ? (_jsx("div", { className: `${dPrefix}checkbox__indeterminate` })) : (checked && _jsx("div", { className: `${dPrefix}checkbox__tick` }))] })), checkNodeExist(children) && _jsx("div", Object.assign({ className: `${dPrefix}checkbox__label` }, { children: children }))] })));
};
DCheckbox.Group = DCheckboxGroup;

==> ui-18.5.2.tgz: package/components/checkbox/Checkbox.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import { checkNodeExist, getClassName } from '@react-devui/utils';
import { useGeneralContext, useDValue } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { DBaseInput } from '../_base-input';
import { useFormControl } from '../form';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DCheckboxGroup } from './CheckboxGroup';
import { DCheckboxGroupRenderer } from './CheckboxGroupRenderer';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DCheckbox' });
export const DCheckbox = (props) => {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dRef, dFormControl, dModel, dVerticalCenter = false, dDisabled = false, dIndeterminate = false, dInputRender, onModelChange } = _a, restProps = __rest(_a, ["children", "dRef", "dFormControl", "dModel", "dVerticalCenter", "dDisabled", "dIndeterminate", "dInputRender", "onModelChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gDisabled } = useGeneralContext();
    //#endregion
    const formControlInject = useFormControl(dFormControl);
    const [checked, changeChecked] = useDValue(false, dIndeterminate ? false : dModel, onModelChange, undefined, formControlInject);
    const disabled = dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled);
    return (_jsxs("label", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}checkbox`, {
            [`${dPrefix}checkbox--vertical-center`]: dVerticalCenter,
            'is-indeterminate': dIndeterminate,
            'is-checked': checked,
            'is-disabled': disabled,
        }) }, { children: [_jsxs("div", Object.assign({ className: `${dPrefix}checkbox__state-container` }, { children: [_jsx(DBaseInput, Object.assign({ dFormControl: dFormControl, dLabelFor: true }, { children: ({ render: renderBaseInput }) => {
                            const input = renderBaseInput(_jsx("input", { ref: dRef === null || dRef === void 0 ? void 0 : dRef.input, className: `${dPrefix}checkbox__input`, type: "checkbox", disabled: disabled, "aria-checked": dIndeterminate ? 'mixed' : checked, onChange: () => {
                                    changeChecked(!checked);
                                } }));
                            return isUndefined(dInputRender) ? input : dInputRender(input);
                        } })), dIndeterminate ? (_jsx("div", { className: `${dPrefix}checkbox__indeterminate` })) : (checked && _jsx("div", { className: `${dPrefix}checkbox__tick` }))] })), checkNodeExist(children) && _jsx("div", Object.assign({ className: `${dPrefix}checkbox__label` }, { children: children }))] })));
};
DCheckbox.Group = DCheckboxGroup;
DCheckbox.GroupRenderer = DCheckboxGroupRenderer;
